==> spip_4.0.4.orig.tar.xz: plugins-dist/forum/lang/forum_en_hx.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=en_hx
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => '70 fu7ur3 4r71c135 0n1y (n0 4c710n 0n 7h3 d474b453).',
	'bouton_radio_articles_tous' => '70 411 4r71c135 w17h0u7 4ny 3xc3p710n.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => '70 411 4r71c135, 3xc3p7 7h053 w17h d154b13d f0rum5.',
	'bouton_radio_enregistrement_obligatoire' => 'R3qu1r3d r3g157r4710n (u53r5 mu57 5ub5cr1b3 by pr0v1d1ng 7h31r 3-m411 4ddr355 b3f0r3 b31ng 4b13 70 p057 c0n7r1bu710n5).',
	'bouton_radio_moderation_priori' => 'B3f0r3h4nd m0d3r4710n (
	c0n7r1bu710n5 w111 b3 5h0wn 0n1y 4f73r v411d4710n by
	4dm1n157r470r5).', # MODIF
	'bouton_radio_modere_abonnement' => 'm0d3r4710n by 5ub5cr1p710n',
	'bouton_radio_modere_posteriori' => '4f73rw4rd5 m0d3r4710n', # MODIF
	'bouton_radio_modere_priori' => 'b3f0r3h4nd m0d3r4710n', # MODIF
	'bouton_radio_publication_immediate' => '1mm3d1473 pub11c4710n 0f m3554g35
	(c0n7r1bu710n5 w111 b3 5h0wn 7h3 m0m3n7 7h3y 4r3 53n7, 4dm1n157r470r5 c4n
	d31373 7h3m 7h3n).',

	// F
	'form_pet_message_commentaire' => '4ny m3554g3 0r c0mm3n7?',
	'forum' => 'F0rum',
	'forum_acces_refuse' => 'Y0u h4v3 n07 4cc355 70 7h353 f0rum5 4nym0r3.',
	'forum_attention_dix_caracteres' => '<b>W4rn1ng!</b> y0ur m3554g3 15 1355 7h4n 73n ch4r4c73r5 1n 13ng7h.', # MODIF
	'forum_attention_trois_caracteres' => '<b>W4rn1ng!</b> y0ur 5ubj3c7 15 1355 7h4n 7hr33 ch4r4c73r5 1n 13ng7h.', # MODIF
	'forum_avez_selectionne' => 'Y0u h4v3 5313c73d:',
	'forum_cliquer_retour' => 'C11ck  <4 hr3f=’@retour_forum@’>h3r3</4> 70 c0n71nu3.',
	'forum_forum' => 'f0rum',
	'forum_info_modere' => '7h15 f0rum 15 m0d3r473d b3f0r3h4nd: y0ur c0n7r1bu710n w111 0n1y 4pp34r 4f73r b31ng v411d473d by 4 5173 4dm1n157r470r.', # MODIF
	'forum_lien_hyper' => '<b>Hyp3r73x7 11nk</b> (0p710n41)', # MODIF
	'forum_message_definitif' => 'F1n41 m3554g3: 53nd 70 7h3 5173',
	'forum_message_trop_long' => 'Y0ur m3554g3 15 700 10ng. M4x1mum 13ng7h 5h0u1d b3 20000 ch4r4c73r5.', # MODIF
	'forum_ne_repondez_pas' => 'D0 n07 r3p1y 70 7h15 m411 bu7 1n 7h3 f0rum 47 7h3 f0110w1ng 4ddr355:', # MODIF
	'forum_page_url' => '(1f y0ur m3554g3 r3f3r5 70 4n 4r71c13 pub115h3d 0n 7h3 w3b 0r 70 4 p4g3 pr0v1d1ng fur7h3r 1nf0rm4710n, p13453 3n73r 7h3 71713 0f 7h3 p4g3 4nd 175 UR1 b310w).',
	'forum_poste_par' => 'M3554g3 p0573d@parauteur@ f0110w1ng y0ur 4r71c13.', # MODIF
	'forum_qui_etes_vous' => '<b>Wh0 4r3 y0u?</b> (0p710n41)', # MODIF
	'forum_texte' => '73x7 0f y0ur m3554g3:', # MODIF
	'forum_titre' => '5ubj3c7:', # MODIF
	'forum_url' => 'UR1:', # MODIF
	'forum_valider' => 'V411d473 7h15 ch01c3',
	'forum_voir_avant' => 'Pr3v13w m3554g3 b3f0r3 p0571ng', # MODIF
	'forum_votre_email' => 'Y0ur 3-m411 4ddr355:', # MODIF
	'forum_votre_nom' => 'Y0ur n4m3 (0r 41145):', # MODIF
	'forum_vous_enregistrer' => 'Pr10r 70 p4r71c1p471ng 1n
		7h15 f0rum, y0u mu57 r3g1573r. 7h4nk y0u
		f0r 3n73r1ng 7h3 p3r50n41 1d3n71f13r
		5upp113d 70 y0u. 1f y0u 4r3 n07 41r34dy r3g1573r3d, y0u mu57',
	'forum_vous_inscrire' => 'r3g1573r </4> f1r57.', # MODIF

	// I
	'icone_poster_message' => 'P057 4 m3554g3',
	'icone_suivi_forum' => 'F0110w-up 0f pub11c f0rum: @nb_forums@ c0n7r1bu710n(5)',
	'icone_suivi_forums' => 'M4n4g3 f0rum5',
	'icone_supprimer_message' => 'D31373 7h15 m3554g3',
	'icone_valider_message' => 'V411d473 7h15 m3554g3',
	'info_activer_forum_public' => '<1>70 3n4b13 pub11c f0rum5, p13453 ch0053 7h31r d3f4u17 m0d3 0f m0d3r4710n:</1>', # MODIF
	'info_appliquer_choix_moderation' => '4pp1y 7h15 ch01c3 0f m0d3r4710n:',
	'info_desactiver_forum_public' => 'D154b13 7h3 u53 0f pub11c
	f0rum5. Pub11c f0rum5 c0u1d b3 4110w3d 0n 4 c453 by c453
	b4515 f0r 7h3 4r71c135; 7h3y w111 b3 f0rb1dd3n f0r 7h3 53c710n5, n3w5, 37c.',
	'info_envoi_forum' => '53nd f0rum5 70 4r71c135 4u7h0r5',
	'info_fonctionnement_forum' => 'F0rum 0p3r4710n:',
	'info_gauche_suivi_forum_2' => '7h3 <1>f0rum5 f0110w-up</1> p4g3 15 4 m4n4g3m3n7 7001 0f y0ur 5173 (n07 4 d15cu5510n 0r 3d171ng). 17 d15p14y5 411 7h3 c0n7r1bu710n5 0f 7h3 pub11c f0rum 0f 7h15 4r71c13 4nd 4110w5 y0u 70 m4n4g3 7h353 c0n7r1bu710n5.', # MODIF
	'info_liens_syndiques_3' => 'f0rum5',
	'info_liens_syndiques_4' => '4r3',
	'info_liens_syndiques_5' => 'f0rum',
	'info_liens_syndiques_6' => '15',
	'info_liens_syndiques_7' => 'p3nd1ng v411d4710n.',
	'info_mode_fonctionnement_defaut_forum_public' => 'D3f4u17 0p3r4710n m0d3 0f pub11c f0rum5',
	'info_option_email' => 'Wh3n 4 5173 v15170r p0575 4 m3554g3 70 7h3 f0rum
		4550c1473d w17h 4n 4r71c13, 7h3 4r71c13’5 4u7h0r5 c4n b3
		1nf0rm3d 0f 7h15 m3554g3 by 3-m411. D0 y0u w15h 70 u53 7h15 0p710n?', # MODIF
	'info_pas_de_forum' => 'n0 f0rum',
	'item_activer_forum_administrateur' => '3n4b13 4dm1n157r470r5 f0rum',
	'item_desactiver_forum_administrateur' => 'D154b13 4dm1n157r470r5 f0rum',

	// L
	'lien_reponse_article' => 'R3p1y 70 7h3 4r71c13',
	'lien_reponse_breve_2' => 'R3p1y 70 7h3 n3w5 173m',
	'lien_reponse_rubrique' => 'R3p1y 70 7h3 53c710n',
	'lien_reponse_site_reference' => 'R3p1y 70 7h3 r3f3r3nc3d 5173:', # MODIF

	// O
	'onglet_messages_internes' => '1n73rn41 m3554g35',
	'onglet_messages_publics' => 'Pub11c m3554g35',
	'onglet_messages_vide' => 'M3554g35 w17h0u7 73x7',

	// R
	'repondre_message' => 'R3p1y 70 7h15 m3554g3',

	// T
	'titre_cadre_forum_administrateur' => '4dm1n157r470r5 pr1v473 f0rum',
	'titre_cadre_forum_interne' => '1n73rn41 f0rum',
	'titre_forum' => 'F0rum',
	'titre_forum_suivi' => 'F0rum5 f0110w-up',
	'titre_page_forum_suivi' => 'F0rum5 f0110w-up'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_en_hx.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=en_hx
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => '70 fu7ur3 4r71c135 0n1y (n0 4c710n 0n 7h3 d474b453).',
	'bouton_radio_articles_tous' => '70 411 4r71c135 w17h0u7 4ny 3xc3p710n.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => '70 411 4r71c135, 3xc3p7 7h053 w17h d154b13d f0rum5.',
	'bouton_radio_enregistrement_obligatoire' => 'R3qu1r3d r3g157r4710n (u53r5 mu57 5ub5cr1b3 by pr0v1d1ng 7h31r 3-m411 4ddr355 b3f0r3 b31ng 4b13 70 p057 c0n7r1bu710n5).',
	'bouton_radio_moderation_priori' => 'B3f0r3h4nd m0d3r4710n (
	c0n7r1bu710n5 w111 b3 5h0wn 0n1y 4f73r v411d4710n by
	4dm1n157r470r5).', # MODIF
	'bouton_radio_modere_abonnement' => 'm0d3r4710n by 5ub5cr1p710n',
	'bouton_radio_modere_posteriori' => '4f73rw4rd5 m0d3r4710n', # MODIF
	'bouton_radio_modere_priori' => 'b3f0r3h4nd m0d3r4710n', # MODIF
	'bouton_radio_publication_immediate' => '1mm3d1473 pub11c4710n 0f m3554g35
	(c0n7r1bu710n5 w111 b3 5h0wn 7h3 m0m3n7 7h3y 4r3 53n7, 4dm1n157r470r5 c4n
	d31373 7h3m 7h3n).',

	// F
	'form_pet_message_commentaire' => '4ny m3554g3 0r c0mm3n7?',
	'forum' => 'F0rum',
	'forum_acces_refuse' => 'Y0u h4v3 n07 4cc355 70 7h353 f0rum5 4nym0r3.',
	'forum_attention_dix_caracteres' => '<b>W4rn1ng!</b> y0ur m3554g3 15 1355 7h4n 73n ch4r4c73r5 1n 13ng7h.', # MODIF
	'forum_attention_trois_caracteres' => '<b>W4rn1ng!</b> y0ur 5ubj3c7 15 1355 7h4n 7hr33 ch4r4c73r5 1n 13ng7h.', # MODIF
	'forum_avez_selectionne' => 'Y0u h4v3 5313c73d:',
	'forum_cliquer_retour' => 'C11ck  <4 hr3f=’@retour_forum@’>h3r3</4> 70 c0n71nu3.',
	'forum_forum' => 'f0rum',
	'forum_info_modere' => '7h15 f0rum 15 m0d3r473d b3f0r3h4nd: y0ur c0n7r1bu710n w111 0n1y 4pp34r 4f73r b31ng v411d473d by 4 5173 4dm1n157r470r.', # MODIF
	'forum_lien_hyper' => '<b>Hyp3r73x7 11nk</b> (0p710n41)', # MODIF
	'forum_message_definitif' => 'F1n41 m3554g3: 53nd 70 7h3 5173',
	'forum_message_trop_long' => 'Y0ur m3554g3 15 700 10ng. M4x1mum 13ng7h 5h0u1d b3 20000 ch4r4c73r5.', # MODIF
	'forum_ne_repondez_pas' => 'D0 n07 r3p1y 70 7h15 m411 bu7 1n 7h3 f0rum 47 7h3 f0110w1ng 4ddr355:', # MODIF
	'forum_page_url' => '(1f y0ur m3554g3 r3f3r5 70 4n 4r71c13 pub115h3d 0n 7h3 w3b 0r 70 4 p4g3 pr0v1d1ng fur7h3r 1nf0rm4710n, p13453 3n73r 7h3 71713 0f 7h3 p4g3 4nd 175 UR1 b310w).',
	'forum_poste_par' => 'M3554g3 p0573d@parauteur@ f0110w1ng y0ur 4r71c13.', # MODIF
	'forum_qui_etes_vous' => '<b>Wh0 4r3 y0u?</b> (0p710n41)', # MODIF
	'forum_texte' => '73x7 0f y0ur m3554g3:', # MODIF
	'forum_titre' => '5ubj3c7:', # MODIF
	'forum_url' => 'UR1:', # MODIF
	'forum_valider' => 'V411d473 7h15 ch01c3',
	'forum_voir_avant' => 'Pr3v13w m3554g3 b3f0r3 p0571ng', # MODIF
	'forum_votre_email' => 'Y0ur 3-m411 4ddr355:', # MODIF
	'forum_votre_nom' => 'Y0ur n4m3 (0r 41145):', # MODIF
	'forum_vous_enregistrer' => 'Pr10r 70 p4r71c1p471ng 1n
		7h15 f0rum, y0u mu57 r3g1573r. 7h4nk y0u
		f0r 3n73r1ng 7h3 p3r50n41 1d3n71f13r
		5upp113d 70 y0u. 1f y0u 4r3 n07 41r34dy r3g1573r3d, y0u mu57',
	'forum_vous_inscrire' => 'r3g1573r </4> f1r57.', # MODIF

	// I
	'icone_poster_message' => 'P057 4 m3554g3',
	'icone_suivi_forum' => 'F0110w-up 0f pub11c f0rum: @nb_forums@ c0n7r1bu710n(5)',
	'icone_suivi_forums' => 'M4n4g3 f0rum5',
	'icone_supprimer_message' => 'D31373 7h15 m3554g3',
	'icone_valider_message' => 'V411d473 7h15 m3554g3',
	'info_activer_forum_public' => '<1>70 3n4b13 pub11c f0rum5, p13453 ch0053 7h31r d3f4u17 m0d3 0f m0d3r4710n:</1>', # MODIF
	'info_appliquer_choix_moderation' => '4pp1y 7h15 ch01c3 0f m0d3r4710n:',
	'info_desactiver_forum_public' => 'D154b13 7h3 u53 0f pub11c
	f0rum5. Pub11c f0rum5 c0u1d b3 4110w3d 0n 4 c453 by c453
	b4515 f0r 7h3 4r71c135; 7h3y w111 b3 f0rb1dd3n f0r 7h3 53c710n5, n3w5, 37c.',
	'info_envoi_forum' => '53nd f0rum5 70 4r71c135 4u7h0r5',
	'info_fonctionnement_forum' => 'F0rum 0p3r4710n:',
	'info_gauche_suivi_forum_2' => '7h3 <1>f0rum5 f0110w-up</1> p4g3 15 4 m4n4g3m3n7 7001 0f y0ur 5173 (n07 4 d15cu5510n 0r 3d171ng). 17 d15p14y5 411 7h3 c0n7r1bu710n5 0f 7h3 pub11c f0rum 0f 7h15 4r71c13 4nd 4110w5 y0u 70 m4n4g3 7h353 c0n7r1bu710n5.', # MODIF
	'info_liens_syndiques_3' => 'f0rum5',
	'info_liens_syndiques_4' => '4r3',
	'info_liens_syndiques_5' => 'f0rum',
	'info_liens_syndiques_6' => '15',
	'info_liens_syndiques_7' => 'p3nd1ng v411d4710n.',
	'info_mode_fonctionnement_defaut_forum_public' => 'D3f4u17 0p3r4710n m0d3 0f pub11c f0rum5',
	'info_option_email' => 'Wh3n 4 5173 v15170r p0575 4 m3554g3 70 7h3 f0rum
		4550c1473d w17h 4n 4r71c13, 7h3 4r71c13’5 4u7h0r5 c4n b3
		1nf0rm3d 0f 7h15 m3554g3 by 3-m411. D0 y0u w15h 70 u53 7h15 0p710n?', # MODIF
	'info_pas_de_forum' => 'n0 f0rum',
	'item_activer_forum_administrateur' => '3n4b13 4dm1n157r470r5 f0rum',
	'item_desactiver_forum_administrateur' => 'D154b13 4dm1n157r470r5 f0rum',

	// L
	'lien_reponse_article' => 'R3p1y 70 7h3 4r71c13',
	'lien_reponse_breve_2' => 'R3p1y 70 7h3 n3w5 173m',
	'lien_reponse_rubrique' => 'R3p1y 70 7h3 53c710n',
	'lien_reponse_site_reference' => 'R3p1y 70 7h3 r3f3r3nc3d 5173:', # MODIF

	// O
	'onglet_messages_internes' => '1n73rn41 m3554g35',
	'onglet_messages_publics' => 'Pub11c m3554g35',
	'onglet_messages_vide' => 'M3554g35 w17h0u7 73x7',

	// R
	'repondre_message' => 'R3p1y 70 7h15 m3554g3',

	// T
	'titre_cadre_forum_administrateur' => '4dm1n157r470r5 pr1v473 f0rum',
	'titre_cadre_forum_interne' => '1n73rn41 f0rum',
	'titre_forum' => 'F0rum',
	'titre_forum_suivi' => 'F0rum5 f0110w-up',
	'titre_page_forum_suivi' => 'F0rum5 f0110w-up',
];
